==> haskell-tasty-smallcheck-0.8.1-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-13YCZFibHRDL4Qg172M4yh
key: tasty-smallcheck-0.8.1-13YCZFibHRDL4Qg172M4yh
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
abi: be009f683bd76971f72c34bb765c5e98
exposed: True
exposed-modules:
    Test.Tasty.SmallCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-13YCZFibHRDL4Qg172M4yh
depends:
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0
    smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK
abi-depends: async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=aec4190e63046da29e6cea1cb38a365c
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK=b3b38fe9dbf8881a7eed1fb4b5bf8074
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.1-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-6H5W7b2I47zIk5namy1Pts
key: tasty-smallcheck-0.8.1-6H5W7b2I47zIk5namy1Pts
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
abi: 219b8b60d026c82a4081faf9421529c7
exposed: True
exposed-modules:
    Test.Tasty.SmallCheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-6H5W7b2I47zIk5namy1Pts
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
    tasty-1.1.0.4-KA2OQv2hxns8llKnTblJO9
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
